@@ -15,7 +15,6 @@
 """EFR32 dev board device class."""
 from gazoo_device import detect_criteria
 from gazoo_device.base_classes import silabs_efr32_device
-from gazoo_device.utility import pwrpc_utils
 
 
 class EFR32(silabs_efr32_device.SilabsEFR32Device):
@@ -26,10 +25,9 @@ class EFR32(silabs_efr32_device.SilabsEFR32Device):
   https://www.silabs.com/documents/public/user-guides/ug342-brd4170a-user-guide.pdf
   """
   DETECT_MATCH_CRITERIA = {
-      detect_criteria.PigweedQuery.product_name: "j-link",
-      detect_criteria.PigweedQuery.manufacturer_name: r"silicon(_| )labs",
-      detect_criteria.PigweedQuery.app_type:
-          pwrpc_utils.PigweedAppType.NON_PIGWEED.value,
+      detect_criteria.PigweedQuery.IS_MATTER: False,
+      detect_criteria.PigweedQuery.MANUFACTURER_NAME: r"silicon(_| )labs",
+      detect_criteria.PigweedQuery.PRODUCT_NAME: "j-link",
   }
   DEVICE_TYPE = "efr32"
   _OWNER_EMAIL = "gdm-authors@google.com"
