@@ -14,28 +14,42 @@
 
 """Matter endpoint and cluster modules."""
 
+from gazoo_device.capabilities.matter_clusters import basic_information_chip_tool
 from gazoo_device.capabilities.matter_clusters import boolean_state_pw_rpc
 from gazoo_device.capabilities.matter_clusters import color_control_pw_rpc
 from gazoo_device.capabilities.matter_clusters import door_lock_pw_rpc
+from gazoo_device.capabilities.matter_clusters import flow_measurement_chip_tool
+from gazoo_device.capabilities.matter_clusters import flow_measurement_pw_rpc
+from gazoo_device.capabilities.matter_clusters import illuminance_measurement_chip_tool
+from gazoo_device.capabilities.matter_clusters import illuminance_measurement_pw_rpc
 from gazoo_device.capabilities.matter_clusters import level_control_chip_tool
 from gazoo_device.capabilities.matter_clusters import level_control_pw_rpc
 from gazoo_device.capabilities.matter_clusters import occupancy_sensing_chip_tool
 from gazoo_device.capabilities.matter_clusters import occupancy_sensing_pw_rpc
 from gazoo_device.capabilities.matter_clusters import on_off_chip_tool
 from gazoo_device.capabilities.matter_clusters import on_off_pw_rpc
+from gazoo_device.capabilities.matter_clusters import pressure_measurement_chip_tool
 from gazoo_device.capabilities.matter_clusters import pressure_measurement_pw_rpc
+from gazoo_device.capabilities.matter_clusters import relative_humidity_measurement_chip_tool
 from gazoo_device.capabilities.matter_clusters import relative_humidity_measurement_pw_rpc
+from gazoo_device.capabilities.matter_clusters import temperature_measurement_chip_tool
 from gazoo_device.capabilities.matter_clusters import temperature_measurement_pw_rpc
+from gazoo_device.capabilities.matter_clusters import thermostat_pw_rpc
 from gazoo_device.capabilities.matter_endpoints import color_temperature_light
 from gazoo_device.capabilities.matter_endpoints import contact_sensor
 from gazoo_device.capabilities.matter_endpoints import dimmable_light
 from gazoo_device.capabilities.matter_endpoints import door_lock
+from gazoo_device.capabilities.matter_endpoints import extended_color_light
+from gazoo_device.capabilities.matter_endpoints import flow_sensor
 from gazoo_device.capabilities.matter_endpoints import humidity_sensor
+from gazoo_device.capabilities.matter_endpoints import light_sensor
 from gazoo_device.capabilities.matter_endpoints import occupancy_sensor
 from gazoo_device.capabilities.matter_endpoints import on_off_light
 from gazoo_device.capabilities.matter_endpoints import on_off_light_switch
 from gazoo_device.capabilities.matter_endpoints import pressure_sensor
+from gazoo_device.capabilities.matter_endpoints import root_node
 from gazoo_device.capabilities.matter_endpoints import temperature_sensor
+from gazoo_device.capabilities.matter_endpoints import thermostat
 import immutabledict
 
 
@@ -44,24 +58,31 @@ SUPPORTED_ENDPOINTS_PW_RPC = (
     contact_sensor.ContactSensorEndpoint,
     dimmable_light.DimmableLightEndpoint,
     door_lock.DoorLockEndpoint,
-    occupancy_sensor.OccupancySensorEndpoint,
+    extended_color_light.ExtendedColorLightEndpoint,
+    flow_sensor.FlowSensorEndpoint,
     humidity_sensor.HumiditySensorEndpoint,
+    light_sensor.LightSensorEndpoint,
+    occupancy_sensor.OccupancySensorEndpoint,
     on_off_light.OnOffLightEndpoint,
     on_off_light_switch.OnOffLightSwitchEndpoint,
     pressure_sensor.PressureSensorEndpoint,
-    temperature_sensor.TemperatureSensorEndpoint)
+    temperature_sensor.TemperatureSensorEndpoint,
+    thermostat.ThermostatEndpoint)
 
 SUPPORTED_CLUSTERS_PW_RPC = (
     color_control_pw_rpc.ColorControlClusterPwRpc,
     boolean_state_pw_rpc.BooleanStateClusterPwRpc,
     door_lock_pw_rpc.DoorLockClusterPwRpc,
+    flow_measurement_pw_rpc.FlowMeasurementClusterPwRpc,
+    illuminance_measurement_pw_rpc.IlluminanceMeasurementClusterPwRpc,
     level_control_pw_rpc.LevelControlClusterPwRpc,
     occupancy_sensing_pw_rpc.OccupancySensingClusterPwRpc,
     on_off_pw_rpc.OnOffClusterPwRpc,
     pressure_measurement_pw_rpc.PressureMeasurementClusterPwRpc,
     (relative_humidity_measurement_pw_rpc.
      RelativeHumidityMeasurementClusterPwRpc),
-    temperature_measurement_pw_rpc.TemperatureMeasurementClusterPwRpc)
+    temperature_measurement_pw_rpc.TemperatureMeasurementClusterPwRpc,
+    thermostat_pw_rpc.ThermostatClusterPwRpc)
 
 MATTER_DEVICE_TYPE_ID_TO_CLASS_PW_RPC = immutabledict.immutabledict({
     endpoint_class.DEVICE_TYPE_ID: endpoint_class
@@ -75,13 +96,26 @@ CLUSTER_ID_TO_CLASS_PW_RPC = immutabledict.immutabledict({
 
 SUPPORTED_ENDPOINTS_CHIP_TOOL = (
     dimmable_light.DimmableLightEndpoint,
+    flow_sensor.FlowSensorEndpoint,
+    humidity_sensor.HumiditySensorEndpoint,
+    light_sensor.LightSensorEndpoint,
     occupancy_sensor.OccupancySensorEndpoint,
-    on_off_light.OnOffLightEndpoint,)
+    on_off_light.OnOffLightEndpoint,
+    pressure_sensor.PressureSensorEndpoint,
+    root_node.RootNodeEndpoint,
+    temperature_sensor.TemperatureSensorEndpoint)
 
 SUPPORTED_CLUSTERS_CHIP_TOOL = (
+    basic_information_chip_tool.BasicInformationClusterChipTool,
+    flow_measurement_chip_tool.FlowMeasurementClusterChipTool,
+    illuminance_measurement_chip_tool.IlluminanceMeasurementClusterChipTool,
     level_control_chip_tool.LevelControlClusterChipTool,
     occupancy_sensing_chip_tool.OccupancySensingClusterChipTool,
     on_off_chip_tool.OnOffClusterChipTool,
+    pressure_measurement_chip_tool.PressureMeasurementClusterChipTool,
+    relative_humidity_measurement_chip_tool.
+    RelativeHumidityMeasurementClusterChipTool,
+    temperature_measurement_chip_tool.TemperatureMeasurementClusterChipTool,
 )
 
 MATTER_DEVICE_TYPE_ID_TO_CLASS_CHIP_TOOL = immutabledict.immutabledict({
